@@ -1,7 +1,11 @@
+from typing import Optional
+
+
 class PlayerCard:
     uuid: str
     display_name: str
     is_hidden_if_not_owned: bool
+    theme_uuid: Optional[str]
     display_icon: str
     small_art: str
     wide_art: str
@@ -13,6 +17,7 @@ class PlayerCard:
         self.uuid = data.get("uuid")
         self.display_name = data.get("displayName")
         self.is_hidden_if_not_owned = data.get("isHiddenIfNotOwned")
+        self.theme_uuid = data.get("themeUuid")
         self.display_icon = data.get("displayIcon")
         self.small_art = data.get("smallArt")
         self.wide_art = data.get("wideArt")
